#
# spec file for package maven-surefire-plugins
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global base_name maven-surefire
Name:           %{base_name}-plugins
Version:        3.5.2
Release:        1.1
Summary:        Test framework project
License:        Apache-2.0 AND CPL-1.0
Group:          Development/Libraries/Java
URL:            https://maven.apache.org/surefire/
Source0:        %{base_name}-%{version}.tar.xz
Source1:        https://www.apache.org/licenses/LICENSE-2.0.txt
Source2:        https://www.eclipse.org/legal/cpl-v10.html
Patch0:         0001-Port-to-TestNG-7.4.0.patch
Patch1:         0002-Unshade-surefire.patch
BuildRequires:  fdupes
BuildRequires:  java-devel >= 1.8
BuildRequires:  maven-local
BuildRequires:  mvn(org.apache.maven.doxia:doxia-core)
BuildRequires:  mvn(org.apache.maven.doxia:doxia-sink-api)
BuildRequires:  mvn(org.apache.maven.plugin-tools:maven-plugin-annotations)
BuildRequires:  mvn(org.apache.maven.plugins:maven-plugin-plugin)
BuildRequires:  mvn(org.apache.maven.reporting:maven-reporting-impl)
BuildRequires:  mvn(org.apache.maven.resolver:maven-resolver-api)
BuildRequires:  mvn(org.apache.maven.shared:maven-shared-utils)
BuildRequires:  mvn(org.apache.maven.surefire:maven-surefire-common)
BuildRequires:  mvn(org.apache.maven.surefire:surefire-api)
BuildRequires:  mvn(org.apache.maven.surefire:surefire-booter)
BuildRequires:  mvn(org.apache.maven.surefire:surefire-extensions-api)
BuildRequires:  mvn(org.apache.maven.surefire:surefire-logger-api)
BuildRequires:  mvn(org.apache.maven.surefire:surefire-report-parser)
BuildRequires:  mvn(org.apache.maven:maven-artifact)
BuildRequires:  mvn(org.apache.maven:maven-core)
BuildRequires:  mvn(org.apache.maven:maven-model)
BuildRequires:  mvn(org.apache.maven:maven-parent:pom:)
BuildRequires:  mvn(org.apache.maven:maven-plugin-api)
BuildRequires:  mvn(org.apache.maven:maven-settings)
BuildRequires:  mvn(org.codehaus.plexus:plexus-i18n)
BuildRequires:  mvn(org.codehaus.plexus:plexus-interpolation)
BuildRequires:  mvn(org.codehaus.plexus:plexus-xml)
BuildRequires:  mvn(org.eclipse.sisu:org.eclipse.sisu.plexus)
BuildRequires:  mvn(org.fusesource.jansi:jansi)
#!BuildRequires: maven-compiler-plugin-bootstrap
#!BuildRequires: maven-jar-plugin-bootstrap
#!BuildRequires: maven-plugin-plugin-bootstrap
#!BuildRequires: maven-resources-plugin-bootstrap
#!BuildRequires: maven-surefire-plugin-bootstrap
BuildArch:      noarch

%description
Surefire is a test framework project.

%package -n maven-surefire-plugin
Summary:        Surefire plugin for maven
Group:          Development/Libraries/Java

%description -n maven-surefire-plugin
Maven surefire plugin for running tests via the surefire framework.

%package -n maven-surefire-report-plugin
Summary:        Surefire reports plugin for maven
Group:          Development/Libraries/Java

%description -n maven-surefire-report-plugin
Plugin for generating reports from surefire test runs.

%package -n maven-failsafe-plugin
Summary:        Maven plugin for running integration tests
Group:          Development/Libraries/Java

%description -n maven-failsafe-plugin
The Failsafe Plugin is designed to run integration tests while the
Surefire Plugins is designed to run unit. The name (failsafe) was
chosen both because it is a synonym of surefire and because it implies
that when it fails, it does so in a safe way.

If you use the Surefire Plugin for running tests, then when you have a
test failure, the build will stop at the integration-test phase and
your integration test environment will not have been torn down
correctly.

The Failsafe Plugin is used during the integration-test and verify
phases of the build lifecycle to execute the integration tests of an
application. The Failsafe Plugin will not fail the build during the
integration-test phase thus enabling the post-integration-test phase
to execute.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Development/Libraries/Java

%description javadoc
Javadoc for %{name}.

%prep
%setup -q -n %{base_name}-%{version}
cp -p %{SOURCE1} %{SOURCE2} .

%patch -P 0 -p1
%patch -P 1 -p1

# Disable strict doclint
sed -i /-Xdoclint:all/d pom.xml

# QA plugin useful only for upstream
%pom_remove_plugin -r :jacoco-maven-plugin
# Not wanted
%pom_remove_plugin -r :maven-shade-plugin
# Not packaged
%pom_remove_plugin -r :animal-sniffer-maven-plugin
# Complains
%pom_remove_plugin -r :apache-rat-plugin

%pom_disable_module surefire-shadefire
%pom_remove_dep -r :surefire-shadefire

# Help plugin is needed only to evaluate effective Maven settings.
# For building RPM package default settings will suffice.
%pom_remove_plugin :maven-help-plugin surefire-its

# We don't need site-source
%pom_remove_plugin :maven-assembly-plugin maven-surefire-plugin

# Disable all modules besides the 3 plugins
for module in \
    maven-surefire-common \
    surefire-api \
    surefire-booter \
    surefire-grouper \
    surefire-extensions-api \
    surefire-extensions-spi \
    surefire-its \
    surefire-logger-api \
    surefire-providers \
    surefire-report-parser; do
  %pom_disable_module ${module}
done

%build
%{mvn_package} ":*tests*" __noinstall
%{mvn_package} ":{surefire,surefire-providers}" __noinstall
%{mvn_package} ":*{surefire-plugin,report-plugin}*" @1
%{mvn_package} ":*junit-platform*" junit5
%{mvn_package} ":*{junit,testng,failsafe-plugin,report-parser}*"  @1

%{mvn_build} -f -- \
%if %{?pkg_vcmp:%pkg_vcmp java-devel >= 9}%{!?pkg_vcmp:0}
    -Dmaven.compiler.release=8 \
%endif
    -Dsource=8

%install
%mvn_install
%fdupes -s %{buildroot}%{_javadocdir}

%files -n maven-surefire-plugin -f .mfiles-surefire-plugin

%files -n maven-surefire-report-plugin -f .mfiles-report-plugin

%files -n maven-failsafe-plugin -f .mfiles-failsafe-plugin

%files javadoc -f .mfiles-javadoc
%license LICENSE-2.0.txt cpl-v10.html

%changelog
* Mon Nov  4 2024 Fridrich Strba <fstrba@suse.com>
- Upgrade to 3.5.2
  * Bug
    + SUREFIRE-2276: JUnit5's TestTemplate failures treated as
    flakes with retries
    + SUREFIRE-2277: RunResult#getFlakes() is lost during
    serialisation/deserialisation to/from failsafe-summary.xml
    + SUREFIRE-2283: FAQ site contains broken link to
    failsafe-plugin
  * Improvement
    + SUREFIRE-2278: Don't say Please
  * Task
    + SUREFIRE-2282: surefire-report-plugin: Update Introduction
    documentation page
  * Dependency upgrade
    + SUREFIRE-2281: Upgrade to Doxia 2.0.0 GA Stack
- Modified patches:
  * 0001-Port-to-TestNG-7.4.0.patch
  * 0002-Unshade-surefire.patch
    + rediff
  * maven-surefire-bootstrap-resources.patch
    + regenerate from non-bootstrap build
* Thu Oct  3 2024 Fridrich Strba <fstrba@suse.com>
- Upgrade to 3.5.1
  * Bug
    + SUREFIRE-1737: Disabling the JUnit5Xml30StatelessReporter has
    no effect
    + SUREFIRE-2257: [REGRESSION] NPEx: Cannot invoke
    "Object.toString()" because "value" is null
    + SUREFIRE-2267: Packages for commons-codec should be relocated
    in surefire-shared-utils
    + SUREFIRE-2268: Tests run under classpath if JDK 23 is used
  * Improvement
    + SUREFIRE-2264: Limit usage of commons-io from
    surefire-shared-utils
    + SUREFIRE-2266: Execute ITs in parallel
    + SUREFIRE-2270: Use JUnit5 in surefire-shadefire
- Upgrade to 3.5.0
  * Improvement
    + SUREFIRE-2227: Dynamically calculate xrefTestLocation
  * Task
    + SUREFIRE-2161: Align Mojo class names and output names
- Upgrade to 3.4.0
  * Bug
    + SUREFIRE-2251: [REGRESSION] java.lang.NoSuchMethodException:
    org.apache.maven.plugin.surefire.StartupReportConfiguration
    .<init>
    + SUREFIRE-2253: [REGRESSION] Bump
    org.apache.commons:commons-compress from 1.26.0 to 1.26.1
    causes hang
  * Improvement
    + SUREFIRE-1385: System properties defined in the Surefire and
    Failsafe plugin configuration should override user properties
- Upgrade to 3.3.1
  * Bug
    + SUREFIRE-2105: Failsafe report size increased with version
    upgrade from 2.17 to 2.22.2
    + SUREFIRE-2242: Plain test report does not include names of the
    skipped tests
    + SUREFIRE-2250: Surefire Test Report Schema properties element
    is not consistent with the code
  * Improvement
    + SUREFIRE-1360: Ability to disable properties for successfully
    passed tests
    + SUREFIRE-1934: Ability to disable system-out/system-err for
    successfully passed tests
    + SUREFIRE-2124: Avoid creating unnecessary target files for pom
    projects
    + SUREFIRE-2249: Doc for 'properties' parameter does not mention
    JUnit
- Upgrade to 3.3.0
  * Bug
    + SUREFIRE-1939: Build fails if java.home has <=2 path
    components
    + SUREFIRE-2232: [REGRESSION] StatelessXmlReporter fails to
    process failed result without a throwable
    + SUREFIRE-2240: Using JUnit BOM prevents upgrading the engine
    version via plugin dependency
  * Improvement
    + SUREFIRE-2248: Make "type" attribute on failures and errors in
    (surefire|failsafe)-test-report schema optional
  * Test
    + SUREFIRE-2141: Surefire 3.0.0-M8 tests don't pass on Mac M1
    (Surefire1295AttributeJvmCrashesToTestsIT)
  * Task
    + SUREFIRE-2244: Make IT for SUREFIRE-1295 reliable
    + SUREFIRE-2246: Clean up dependencies reported by
    dependencies:analyze
- Modified patches:
  * maven-surefire-bootstrap-resources.patch
    + regenerate from non-bootstrap build
  * 0001-Port-to-TestNG-7.4.0.patch
    + rediff and augment to make the test pass in upstream evironment
- Added patch:
  * 0002-Unshade-surefire.patch
    + remove the use of the shaded surefire-shared-utils artifact
    in favour of direct use of the dependencies
* Wed Apr 10 2024 Fridrich Strba <fstrba@suse.com>
- Upgrade to 3.2.5
  * Bug
    + SUREFIRE-2223: Surefire evaluates parameter jvm before skip
    + SUREFIRE-2224: StatelessXmlReporter#getTestProblems() does
    not properly reflect report schema structure
    + SUREFIRE-2225: Surefire ITs fail when project directory
    contains space
    + SUREFIRE-2229: + REGRESSION] SUREFIRE-2224 causes stack trace
    to be omitted for errors and failures
    + SUREFIRE-2231: JaCoCo 0.8.11 fails with old TestNG releases on
    Java 17+
  * Improvement
    + SUREFIRE-1345: Support flakyFailure and flakyError in
    TestSuiteXmlParser
    + SUREFIRE-2221: Document minimum supported Java version for
    Toolchains
- Upgrade to 3.2.3
  * Bug
    + SUREFIRE-2210: Additional class path ordering broken since
    3.2.0
    + SUREFIRE-2211: additionalClasspathElement with UNC path not
    working with Maven Failsafe Plugin
    + SUREFIRE-2212: OutOfMemoryError raised when parsing files with
    huge stderr/stdout output in surefire-report-parser
    + SUREFIRE-2220:
    SurefireForkChannel#getForkNodeConnectionString() returns
    invalid URI string if localHost resolves to IPv6 address
  * Dependency upgrade
    + SUREFIRE-2214: Upgrade to HtmlUnit 3.8.0
    + SUREFIRE-2215: Upgrade to Parent 41
    + SUREFIRE-2216: Upgrade plugins and components (in ITs)
- Upgrade to 3.2.2
  * Bug Fixes
    + SUREFIRE-2205: Use maven-plugin-report-plugin only in plugins
    modules
    + SUREFIRE-2206: Downgrade plexus-xml to 3.0.0
  * Dependency updates
    + SUREFIRE-2208: Bump org.codehaus.plexus:plexus-java from 1.1.2
    to 1.2.0
- Upgrade to 3.2.1
  * New features and improvements
    + SUREFIRE-1124: Support forkNumber in environment variables
    + SUREFIRE-2177: Use junit-bom instead of single JUnit 5
    versions
    + SUREFIRE-2179: Support adding additional Maven dependencies to
    the test runtime classpath
    + SUREFIRE-2178: clarify classpathDependencyExcludes
    + SUREFIRE-2182: Log starter implementation on DEBUG level
  * Bug Fixes
    + SUREFIRE-2190: Fix module dependencies for compile only
    dependencies
  * Documentation updates
    + Fix TestNG web site URL (#671) @sabi0
- Upgrade to 3.1.2
  * Changes
    + SUREFIRE-2166: Use ChoiceFormat to selective render percentage
    and elapsed time in SurefireReportRenderer
    + Simplify serialization/deserialization of elapsed time
    (SUREFIRE-2164 + SUREFIRE-2167)
    + SUREFIRE-2169: Potential NPE in WrappedReportEntry when
    [#]getElapsed() is called
    + MNG-6829: Replace StringUtils#isEmpty(String) and
    [#]isNotEmpty(String)
- Upgrade to 3.1.0
  * Sub-task
    + SUREFIRE-2162: Document upcoming mojo and file names change
  * Bug
    + SUREFIRE-2140: Cannot release Surefire on Windows
  * Improvement
    + SUREFIRE-2153: Replace SurefireReportGenerator with a new
    SurefireReportRenderer
    + SUREFIRE-2160: Replace LocalizedProperties with (Custom)I18N
    approach from MPIR
  * Task
    + SUREFIRE-2130: Rewrite several test classes in report
    plugin for upcoming Doxia 2.0.0 stack
- Upgrade to 3.0.0
  * New features and improvements
    + SUREFIRE-2154: Get rid of localRepository from surefire
    mojo parameter, use Resolver API
  * Bug Fixes
    + SUREFIRE-2119: Sanitize failIfNoSpecifiedTests prefix in
    failsafe
    + SUREFIRE-2143: Fix reporting of skipped parameterized test
  * Documentation updates
    + SUREFIRE-2156: Refresh download page
- Modifed patch:
  * 0003-Port-to-TestNG-7.4.0.patch -> 0001-Port-to-TestNG-7.4.0.patch
    + regenerate
  * maven-surefire-bootstrap-resources.patch
    + regenerate from maven build
- Removed patches:
  * 0001-Maven-3.patch
  * 0002-Port-to-current-doxia.patch
  * 0004-Port-to-current-maven-shared-utils.patch
    + not needed with this version
* Thu Feb 22 2024 Fridrich Strba <fstrba@suse.com>
- Upgrade to 2.22.2
  * Bugs:
    + SUREFIRE-1614: JUnit Runner that writes to System.out
    corrupts Surefire’s STDOUT when using JUnit’s Vintage Engine
- Upgrade to 2.22.1
  * Bugs:
    + SUREFIRE-1532: MIME type for javascript is now officially
    application/javascript
    + SUREFIRE-1535: Surefire unable to run testng suites in
    parallel
    + SUREFIRE-1538: Git considers PNG files as changed although
    there is no change
    + SUREFIRE-1550: The surefire XSD published on maven site lacks
    of some rerun element
    + SUREFIRE-1559: XML Report elements rerunError, rerunFailure,
    flakyFailure, flakyError should contain element stackTrace and
    should not be simpleContent.
    + SUREFIRE-1561: Logs in Parallel Tests are mixed up when
    forkMode=never or forkCount=0
    + SUREFIRE-1564: Can’t override platform version through
    project/plugin dependencies
    + SUREFIRE-1579: Forks mixed up characters in standard output
  * Improvements:
    + SUREFIRE-1552: Nil element “failureMessage” in
    failsafe-summary.xml should have self closed tag
    + SUREFIRE-1554: Fix old test resources TEST-*.xml in favor of
    continuing with SUREFIRE-1550
    + SUREFIRE-1555: Elapsed time in XML Report should satisfy
    pattern in XSD.
    + SUREFIRE-1562: Support Java 11
    + SUREFIRE-1565: Surefire should support parameterized
    reportsDirectory
  * Tasks:
    + SUREFIRE-1569: m-invoker-p:3.1.0 attempts to resolve
    maven-surefire-common:jar:2.22.1-SNAPSHOT from remote repo
    'apache.snapshots'
    + SUREFIRE-1578: Remove obsolete module
    surefire-setup-integration-tests
  * Dependency upgrades:
    + SUREFIRE-1540: Upgrade maven-plugins parent to version 32
    + SUREFIRE-1571: Upgrade maven-plugins parent to version 33
- Fetch sources using source service to avoid bundling binaries in
  sources
- Fix broken links in the spec file
- Modified patch:
  * 0004-Port-to-current-maven-shared-utils.patch
    + rediff to changed context
* Thu May  5 2022 Fridrich Strba <fstrba@suse.com>
- Clean and simplify the spec file in order to be able to generate
  the javadoc with either maven-javadoc-plugin or xmvn javadoc mojo
* Wed Apr 27 2022 Fridrich Strba <fstrba@suse.com>
- Modified patches:
  * 0004-Port-to-current-maven-shared-utils.patch
    + Add some try/catch blocks so that we catch new exceptions
    potentially thrown by maven-shared-utils-3.3.x
  * 0003-Port-to-TestNG-6.11.patch -> 0003-Port-to-TestNG-7.4.0.patch
    + Allow building with the new testng 7.4.0
* Tue Mar 22 2022 Fridrich Strba <fstrba@suse.com>
- Build with source and target level 8
* Mon Apr 19 2021 Pedro Monreal <pmonreal@suse.com>
- Update generate-tarball.sh to use https URL [bsc#1182708]
* Sun Nov 24 2019 Fridrich Strba <fstrba@suse.com>
- Specify maven.compiler.release to fix build with jdk9+ and newer
  maven-javadoc-plugin
* Wed Apr  3 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of the non-bootstrap versions of maven plugins
  distributed with surefire 2.22.0
